package com.ruoyi.system.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.system.domain.PoCollection;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Update;

import java.util.List;

/**
 * 藏品表 数据层
 *
 * @author blue
 */
@Mapper
public interface PoCollectionMapper extends BaseMapper<PoCollection> {
    /**
     * 查询藏品列表
     *
     * @param poCollection 藏品信息
     * @return 藏品集合
     */
    List<PoCollection> selectPoCollectionList(PoCollection poCollection);

    /**
     * 新增藏品
     *
     * @param collections 藏品信息
     * @return 结果
     */
    int insertPoCollection(PoCollection collections);

    /**
     * 新增藏品
     *
     * @param collections 藏品信息
     * @return 结果
     */
    int batchInsertPoCollection(List<PoCollection> collections);

    /**
     * 修改藏品
     *
     * @param collections 藏品信息
     * @return 结果
     */
    int updatePoCollection(PoCollection collections);

    /**
     * 定时更新藏品状态
     */
    @Update("update po_collection set status = " +
            "case when now() > show_start then 2 " +
            "when show_end > now() then 1 " +
            "when now() >= show_start and show_end >= now() then 0 " +
            "end;")
    void updateCollectionStatus();

    /**
     * 售卖藏品
     *
     * @param collectionId 藏品ID
     * @param count        售卖数量
     * @return 操作结果
     */
    @Update("update po_collection set count = count - #{count}," +
            "sold_out = case when count > 0 then 0 when count = 0 then 0 end " +
            "where collection_id = #{collectionId} and sold_out = 0 and count >= #{count}")
    int updateSellCount(Long collectionId, Long count);
}
