package com.ruoyi.system.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ruoyi.system.domain.PoCollection;
import com.ruoyi.system.mapper.PoCollectionMapper;
import com.ruoyi.system.service.IPoCollectionService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Arrays;
import java.util.Date;
import java.util.List;

@Service
public class PoCollectionServiceImpl implements IPoCollectionService {
    @Autowired
    PoCollectionMapper poCollectionMapper;

    /**
     * 藏品列表搜索Wrapper
     *
     * @param col 查询条件
     * @return wrapper
     */
    QueryWrapper<PoCollection> genWrapper(PoCollection col) {
        QueryWrapper<PoCollection> wrapper = new QueryWrapper<>();
        if (col == null)
            return wrapper;
        if (col.getCollectionTitle() != null && !col.getCollectionTitle().isEmpty())
            wrapper.like("collection_title", col.getCollectionTitle());
        if (col.getShowStart() != null)
            wrapper.ge("show_start", col.getShowStart());
        if (col.getShowEnd() != null)
            wrapper.le("show_end", col.getShowEnd());
        if (col.getStatus() != null)
            wrapper.eq("status", col.getStatus());
        wrapper.eq("del_flag", col.getDelFlag() == null ? 0 : col.getDelFlag());
        return wrapper;
    }

    /**
     * 查询藏品列表
     *
     * @param poCollection 藏品信息
     * @return 藏品列表
     */
    @Override
    public List<PoCollection> selectPoCollectionList(PoCollection poCollection) {
        return poCollectionMapper.selectList(genWrapper(poCollection));
    }

    /**
     * 搜索藏品列表
     *
     * @param collectionName 藏品名字(模糊查询)
     * @param startTime      创建时间起始
     * @param endTime        创建时间结束
     * @return 藏品列表
     */
    @Override
    public List<PoCollection> queryPoCollectionList(String collectionName, Date startTime, Date endTime, Long status, Long delFlag) {
        PoCollection col = new PoCollection();
        col.setCollectionTitle(collectionName);
        col.setStatus(status);
        col.setShowStart(startTime);
        col.setShowEnd(endTime);
        col.setDelFlag(delFlag);
        return poCollectionMapper.selectList(genWrapper(col));
    }

    /**
     * 获取藏品详细内容
     *
     * @param collectionId 藏品ID
     * @return 藏品信息
     */
    @Override
    public PoCollection selectCollectionById(Long collectionId) {
        return poCollectionMapper.selectById(collectionId);
    }


    /**
     * 添加藏品
     *
     * @param collection 藏品信息
     * @return 操作状态
     */
    @Override
    public int insertCollection(PoCollection collection) {
        return poCollectionMapper.insert(collection);
    }

    /**
     * 批量添加藏品
     *
     * @param collectionList 藏品信息
     * @return 操作状态
     */
    @Override
    public int batchInsertCollection(List<PoCollection> collectionList) {
        return poCollectionMapper.batchInsertPoCollection(collectionList);
    }

    /**
     * 修改
     *
     * @param collection 更新的藏品信息
     * @return 操作状态
     */
    @Override
    public int updateCollection(PoCollection collection) {
        return poCollectionMapper.updatePoCollection(collection);
    }

    /**
     * 批量删除藏品
     *
     * @param collectionIds 需要删除的藏品ID
     * @return 操作结果
     */
    @Override
    public int deletePoCollectionByCollectionIds(Long[] collectionIds) {
        return poCollectionMapper.deleteBatchIds(Arrays.asList(collectionIds));
    }

    /**
     * 定时更新藏品状态
     */
    @Override
    public void updateCollectionStatus() {
        poCollectionMapper.updateCollectionStatus();
    }
}
